@@ -705,7 +705,7 @@ bfGenerateClasses <- function(types, verbose = FALSE, where = .GlobalEnv){
 
 ##' All betfair functions are capable of producing a valid S4 object
 ##' corresponding to betfair SOAP specification. \cr For parsimony reasons the
-##' betfair S4 classes are not installed with the package. You need \code{
+##' betfair S4 classes are not installed with the package. You need to run \code{
 ##' bfInitClasses()} to initialize them. Note that \code{XMLSchema} package is
 ##' required for this initialization.
 ##'
@@ -737,12 +737,14 @@ bfInitClasses <- function(verbose = FALSE, where = .GlobalEnv){
     ## write(getURI("https://api.betfair.com/exchange/v5/BFExchangeService.wsdl "),tmp <- tempfile())
     ## ExUK <- processWSDL(tmp)
 ### CLASSES
-    bfGenerateClasses(Gl_types, verbose = verbose)
-    bfGenerateClasses(ExUK_types, verbose = verbose)
+    bfGenerateClasses(get("Gl_types"), verbose = verbose) ## get to silence the R CMD check
+    bfGenerateClasses(get("ExUK_types"), verbose = verbose)
 }
 
 
-
+.onLoad <- function(libname, pkgname){
+    assign(".sessionToken", "", envir = .GlobalEnv)
+}
 ## Local Variables:
 ## ess-roxy-template-alist: (
 ##  ("description" . "..description")
